<?php

declare(strict_types=1);

namespace Kylin\Retail\Enums;

/**
 * 会员状态枚举
 */
enum MemberStatus: int
{
    case Active   = 1; // 正常
    case Disabled = 0; // 禁用

    public function label(): string
    {
        return match ($this) {
            self::Active   => '正常',
            self::Disabled => '禁用',
        };
    }
}
