<?php

declare(strict_types=1);

namespace Kylin\Retail\Enums;

/**
 * 商品状态枚举
 */
enum ProductStatus: int
{
    case OnSale   = 1; // 上架
    case OffShelf = 0; // 下架

    public function label(): string
    {
        return match ($this) {
            self::OnSale   => '上架',
            self::OffShelf => '下架',
        };
    }
}
