<?php

declare(strict_types=1);

namespace Kylin\Retail\Facades;

use Illuminate\Support\Facades\Facade;

/**
 * @see \Kylin\Retail\RetailServiceProvider
 */
class KylinRetail extends Facade
{
    protected static function getFacadeAccessor(): string
    {
        return 'kylin-retail';
    }
}
