<?php

declare(strict_types=1);

namespace Kylin\Retail;

use Illuminate\Support\ServiceProvider;

/**
 * 零售系统服务提供者
 *
 * 提供零售门店管理核心功能，包括商品管理、
 * 库存管理、销售记录等。
 */
class RetailServiceProvider extends ServiceProvider
{
    public function register(): void
    {
        $this->mergeConfigFrom(
            __DIR__.'/../config/kylin-retail.php', 'kylin-retail'
        );
    }

    public function boot(): void
    {
        // 发布配置
        $this->publishes([
            __DIR__.'/../config/kylin-retail.php' => config_path('kylin-retail.php'),
        ], 'kylin-retail-config');

        // 发布迁移
        $this->publishes([
            __DIR__.'/../database/migrations' => database_path('migrations'),
        ], 'kylin-retail-migrations');

        // 加载路由
        $this->loadRoutesFrom(__DIR__.'/../routes/api.php');

        // 加载迁移
        $this->loadMigrationsFrom(__DIR__.'/../database/migrations');

        // 控制台命令
        if ($this->app->runningInConsole()) {
            $this->commands([]);
        }
    }
}
