<?php

declare(strict_types=1);

namespace Kylin\Retail\Enums;

/**
 * 支付方式枚举
 */
enum PayMethod: string
{
    case Wechat  = 'wechat';   // 微信支付
    case Alipay  = 'alipay';   // 支付宝
    case Card    = 'card';     // 银行卡
    case Cash    = 'cash';     // 现金
    case Balance = 'balance';  // 会员余额
    case Mixed   = 'mixed';   // 混合支付

    public function label(): string
    {
        return match ($this) {
            self::Wechat  => '微信支付',
            self::Alipay  => '支付宝',
            self::Card    => '银行卡',
            self::Cash    => '现金',
            self::Balance => '会员余额',
            self::Mixed   => '混合支付',
        };
    }
}
